@@ -17,6 +17,7 @@ class driveLoader(BaseLoader):
             gauth = GoogleAuth()
             gauth.LoadCredentialsFile(client)
             if gauth.credentials is None:
+                # Authenticate if they're not there
                 gauth.LocalWebserverAuth() # Creates local webserver and auto handles authentication.
                 # Save the current credentials to a file
             elif gauth.access_token_expired:
@@ -37,3 +38,13 @@ class driveLoader(BaseLoader):
                 self.load_from_string(content)
         except Exception as err:
             raise Exception('Error loading Environment: {}'.format(err))
+
+    def save_enviroment(self, path:str=None):
+        try:
+            env = self.drive.CreateFile({'id': self.file_id})
+            content = env.GetContentString()
+            if content:
+                with open(path, 'w+') as f:
+                    f.write(content)
+        except Exception as err:
+            raise Exception('Error Saving Environment: {}'.format(err))
